@@ -1,11 +1,11 @@
-import logbook
+import logging
 from inflection import underscore
 
 from regipy import RegistryKeyNotFoundException, convert_wintime
 from regipy.hive_types import NTUSER_HIVE_TYPE
 from regipy.plugins.plugin import Plugin
 
-logger = logbook.Logger(__name__)
+logger = logging.getLogger(__name__)
 
 
 TYPED_URLS_KEY_PATH = r'\Software\Microsoft\Internet Explorer\TypedURLs'
